@@ -334,6 +334,7 @@ void MainWindow::newConnection(const KUrl &newUrl, bool switchFullscreenWhenConn
     connect(view, SIGNAL(statusChanged(RemoteView::RemoteStatus)), this, SLOT(statusChanged(RemoteView::RemoteStatus)));
     connect(view, SIGNAL(disconnected()), this, SLOT(disconnectHost()));
 
+    view->winId();  // native widget workaround for bug 253365
     QScrollArea *scrollArea = createScrollArea(m_tabWidget, view);
 
     const int indexOfNewConnectionWidget = m_tabWidget->indexOf(m_newConnectionWidget);
@@ -668,8 +669,8 @@ void MainWindow::showConnectionContextMenu(const QPoint &pos)
         return;
 
     const QString url = index.data(10001).toString();
-    const QString title = m_remoteDesktopsModel->index(index.row(), RemoteDesktopsModel::Title).data(Qt::DisplayRole).toString();
-    const QString source = m_remoteDesktopsModel->index(index.row(), RemoteDesktopsModel::Source).data(Qt::DisplayRole).toString();
+    const QString title = index.model()->index(index.row(), RemoteDesktopsModel::Title).data(Qt::DisplayRole).toString();
+    const QString source = index.model()->index(index.row(), RemoteDesktopsModel::Source).data(Qt::DisplayRole).toString();
 
     KMenu *menu = new KMenu(m_newConnectionTableView);
     menu->addTitle(url);
